@@ -8,7 +8,7 @@ from collections import Counter
 import seaborn as sb
 import numpy as np
 import matplotlib.pyplot as plt
-plt.style.use('seaborn')
+
 import scipy.optimize as optim
 from scipy.optimize import curve_fit
 from scipy.stats import logser
@@ -148,7 +148,7 @@ def abundance_histogram(x, ax=None, figsize=None, trendline=False):
 
 
 def density(d, empirical=None, title=None, ax=None, xlim=None,
-            xlabel=None, ylabel=None, figsize=None):
+            xlabel=None, ylabel='Density (KDE)', figsize=None):
     r"""
     Plot histogram and kernel density of a bootstrapped
     richness estimate, with vertical lines for the quartiles
@@ -185,34 +185,32 @@ def density(d, empirical=None, title=None, ax=None, xlim=None,
     if ax is None:
         fig, ax = plt.subplots(figsize=figsize)
 
-    sb.histplot(d['bootstrap'], kde=True, ax=ax)
+    sb.histplot(d['bootstrap'], color="C0", kde=True, ax=ax)
 
     q_11, q_50, q_89 = stats.quantile(d['bootstrap'], [0.11, 0.5, 0.89], weights=None)
     q_m, q_p = q_50 - q_11, q_89 - q_50
 
-    ax.axvline(q_50, color='red')
-    ax.axvline(q_11, ls='--', color='red')
-    ax.axvline(q_89, ls='--', color='red')
+    ax.axvline(q_50, color='C3')
+    ax.axvline(q_11, ls='--', color='C3')
+    ax.axvline(q_89, ls='--', color='C3')
 
     if empirical:
-        ax.axvline(empirical, ls='--', color='green', linewidth=2)
+        ax.axvline(empirical, ls='--', color='C1', linewidth=2)
 
-    # Format the quantile display.
+    # Format the quantile display:
     fmt = "{{0:{0}}}".format(".2f").format
     textstr = r"${{{0}}}_{{-{1}}}^{{+{2}}}$"
     textstr = textstr.format(fmt(q_50), fmt(q_m), fmt(q_p))
     textstr = 'Estimate: ' + textstr
 
-    ax.annotate(textstr, xy=(0.5, 0.7), xycoords='axes fraction',
-                va='center_baseline', backgroundcolor='white')
-
     ax.set(
         xlim=xlim,
         xlabel=xlabel,
         ylabel=ylabel,
-        title="Estimate: bootstrap values (KDE and quartiles)" if not title else title
     )
 
+    ax.text(0.6, 0.8, textstr, transform=ax.transAxes)
+
     return ax
 
 
@@ -253,7 +251,7 @@ def multi_kde(assemblages, ax=None, figsize=None,
     for i, (label, assemblage) in enumerate(assemblages.items()):
         sb.kdeplot(assemblage['bootstrap'], label=label,
                    ax=ax, color=f"C{i}", shade=True)
-        ax.axvline(assemblage['survival'], linewidth=2, color=f"C{i}")
+        ax.axvline(assemblage['survival'], ls='--', linewidth=1, color=f"C{i}")
 
     ax.set_xlim(xlim)
     ax.set_xlabel(xlabel)
@@ -264,7 +262,7 @@ def multi_kde(assemblages, ax=None, figsize=None,
 
 
 def survival_errorbar(survival, ax=None, figsize=None, xlabel=None,
-                      ylabel='label'):
+                      ylabel='label', sort_values=False):
     r"""
     Takes a dict of survival estimates for labeled assem-
     blages and plots the bootstrap value as error bars,
@@ -285,6 +283,8 @@ def survival_errorbar(survival, ax=None, figsize=None, xlabel=None,
         The label for the primary x-axis in the plot
     ylabel : str (default = None)
         The label for the primary y-axis in the plot
+    sort_values : bool (default = False)
+        Whether to sort the bars (ascendingly)
     figsize : 2-way tuple (default = None)
         The size of the new plt.Figure to be plotted
         (Ignored if an axis is passed.)
@@ -298,7 +298,8 @@ def survival_errorbar(survival, ax=None, figsize=None, xlabel=None,
     for l in survival:
         estimates.append([l] + [survival[l][k] for k in ['survival', 'lci', 'uci']])
     estimates = pd.DataFrame(estimates, columns=[ylabel, 'survival', 'lci', 'uci'])
-    estimates = estimates.sort_values('survival')
+    if sort_values:
+        estimates = estimates.sort_values('survival')
     errors = np.array(list(zip(estimates['lci'], estimates['uci']))).T
     errors[0] = estimates['survival'] - errors[0]
     errors[1] -= estimates['survival']
@@ -311,12 +312,12 @@ def survival_errorbar(survival, ax=None, figsize=None, xlabel=None,
         estimates['survival'],
         yerr=errors,
         fmt='.',
-        c='green',
+        c='C5',
         label='diversity',
         ms=12)
 
     ax.set_ylabel(ylabel)
-    ax.set_ylabel(xlabel)
+    ax.set_xlabel(xlabel)
     ax.set_xticks(np.arange(len(estimates)))
     ax.set_xticklabels(estimates[ylabel])
 
@@ -324,7 +325,8 @@ def survival_errorbar(survival, ax=None, figsize=None, xlabel=None,
 
 
 def accumulation_curve(x, accumulation, minsample=None,
-                       ax=None, figsize=None, **kwargs):
+                       ax=None, figsize=None, c0='C0',
+                       c1='C1', **kwargs):
     r"""
     Plots the species accumulation curve for an assemblage,
     with the option of adding a kernel density plot for a
@@ -345,6 +347,10 @@ def accumulation_curve(x, accumulation, minsample=None,
     ax : plt.Axes (default = None)
         The ax to plot on or None if a new plt.Figure
         is required.
+    c0 : str (default = "C0")
+        Color string for the species accumulation curve
+    c1 : str (default = "C1")
+        Color string for the minsample curve
     figsize : 2-way tuple (default = None)
         The size of the new plt.Figure to be plotted
         (Ignored if an axis is passed.)
@@ -369,20 +375,23 @@ def accumulation_curve(x, accumulation, minsample=None,
         fig, ax = plt.subplots(figsize=figsize)
 
     # mark empirical situation:
-    ax.plot(x.sum(), Dq[x.sum() - 1], 'o', markersize=8)
-    ax.plot(steps[interpolated], Dq[interpolated], color='C0')
-    ax.plot(steps[~interpolated], Dq[~interpolated], '--', color='C0')
-    ax.fill_between(steps, lci, uci, alpha=0.3)
+    ax.plot(x.sum(), Dq[x.sum() - 1], 'o', markersize=8, color=c0)
+    ax.plot(steps[interpolated], Dq[interpolated], color=c0)
+    ax.plot(steps[~interpolated], Dq[~interpolated], '--', color=c0)
+    ax.fill_between(steps, lci, uci, alpha=0.3, color=c0)
 
     if minsample:
         ax2 = ax.twinx()
         sb.kdeplot(minsample['bootstrap'], ax=ax2,
-                   color='green', fill=True)
+                    color=c1, fill=True)
 
-        ax.axvline(minsample['richness'], color='green')
+        ax.axvline(minsample['richness'], color=c1)
 
-        ax2.grid(None)
         ax2.set(xlabel='Min. add. sample')
+        ax2.ticklabel_format(style='sci', axis='y', scilimits=(0, 0))
+        ax2.get_yaxis().get_offset_text().set_position((1.15, 0))
+        ax2.tick_params(axis='y', which='minor', right=False)
+        plt.setp(ax2.get_yticklabels()[0], visible=False)
 
     # cosmetics etc.
     ax.set(**kwargs)
@@ -466,11 +475,12 @@ def hill_plot(emp, est, q_min=0, q_max=3, step=0.1,
         Minimum order to consider
     q_max : float (default = 3)
         Maximum order to consider
+    step : float (default = 0.1)
+        Step size in between consecutive orders
     add_densities: bool (default = True)
         If True, kernel densitity estimates for the main
         orders q will be added in a separate subplot
-    step : float (default = 0.1)
-        Step size in between consecutive orders
+    
     title : str (default = None)
         The main title for the figure
     ax : plt.Axes (default = None)
@@ -510,14 +520,14 @@ def hill_plot(emp, est, q_min=0, q_max=3, step=0.1,
     ax.fill_between(q, lci_emp, uci_emp, color=c_emp, alpha=0.3)
     ax.fill_between(q, lci_est, uci_est, color=c_est, alpha=0.3)
 
-    ax.set(xlabel='Order $q$', ylabel='Hill numbers', ylim=(y_min, y_max),
+    ax.set(xlabel='Diversity order $q$', ylabel='Hill numbers', ylim=(y_min, y_max),
            title=title)
 
     ax.legend(
-        bbox_to_anchor=(0.0, 1.02, 1.0, 0.102),
+        bbox_to_anchor=(0.5, 1.05),
         loc='upper center',
-        ncol=3,
-        mode='expand',
+        ncol=2,
+        # mode='expand',
         borderaxespad=0.0,
         facecolor='white',
         framealpha=1,
@@ -592,9 +602,9 @@ def evenness_plot(evennesses, q_min=0, q_max=3, step=0.1, ax=None,
     q = np.arange(q_min, q_max + step, step)
 
     for i, (label, evenness) in enumerate(evennesses.items()):
-        ax.plot(q, evenness, label=label, c=f"C{i}", linewidth=2)
+        ax.plot(q, evenness, label=label, c=f"C{i}")
 
-    ax.set_xlabel('Diversity order ($q$)')
+    ax.set_xlabel('Diversity order $q$')
     ax.set_ylabel(r'Evenness: $({}^qD - 1) / (\hat{S} - 1)$')
     ax.set_title('Evenness profile')
     ax.legend(loc='best')
